#ifndef ACCOUNTSDIALOG_H
#define ACCOUNTSDIALOG_H

#include <QDialog>
#include <QModelIndex>

class AccountsDialog : public QDialog
{
        Q_OBJECT
 public:
        AccountsDialog(QWidget *parent = 0,
                       Qt::WindowFlags f = 0);

 signals:
        void newAccountSelected();
        void accountDetailsSelected(const QModelIndex &index);
};
#endif
